# WorldOfGames

DevOps Course Project.
Holding from initial Python3 designing and coding to a Jenkins pipeline.

Living the CI/CD process and showing its usage throughout from:
Planning -> Coding -> Building packages -> Create containers and their network -> Full deployment in Kubernetes
